==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/NetNamespaceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetNamespaceBuilder extends io.fabric8.openshift.api.model.NetNamespaceFluentImpl<io.fabric8.openshift.api.model.NetNamespaceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.NetNamespace,io.fabric8.openshift.api.model.NetNamespaceBuilder>{
  public NetNamespaceBuilder() {
    this(false);
  }
  public NetNamespaceBuilder(java.lang.Boolean validationEnabled) {
    this(new NetNamespace(), validationEnabled);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent) {
    this(fluent, false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetNamespace(), validationEnabled);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,io.fabric8.openshift.api.model.NetNamespace instance) {
    this(fluent, instance, false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,io.fabric8.openshift.api.model.NetNamespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withEgressIPs(instance.getEgressIPs()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withNetid(instance.getNetid()); 
    fluent.withNetname(instance.getNetname()); 
    this.validationEnabled = validationEnabled; 
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespace instance) {
    this(instance,false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withEgressIPs(instance.getEgressIPs()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withNetid(instance.getNetid()); 
    this.withNetname(instance.getNetname()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.NetNamespace build() {
    NetNamespace buildable = new NetNamespace(fluent.getApiVersion(),fluent.getEgressIPs(),fluent.getKind(),fluent.getMetadata(),fluent.getNetid(),fluent.getNetname());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetNamespaceBuilder that = (NetNamespaceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/NetNamespaceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetNamespaceBuilder extends io.fabric8.openshift.api.model.NetNamespaceFluentImpl<io.fabric8.openshift.api.model.NetNamespaceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.NetNamespace,io.fabric8.openshift.api.model.NetNamespaceBuilder>{
  public NetNamespaceBuilder() {
    this(false);
  }
  public NetNamespaceBuilder(java.lang.Boolean validationEnabled) {
    this(new NetNamespace(), validationEnabled);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent) {
    this(fluent, false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetNamespace(), validationEnabled);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,io.fabric8.openshift.api.model.NetNamespace instance) {
    this(fluent, instance, false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent,io.fabric8.openshift.api.model.NetNamespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withEgressIPs(instance.getEgressIPs()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withNetid(instance.getNetid()); 
    fluent.withNetname(instance.getNetname()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespace instance) {
    this(instance,false);
  }
  public NetNamespaceBuilder(io.fabric8.openshift.api.model.NetNamespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withEgressIPs(instance.getEgressIPs()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withNetid(instance.getNetid()); 
    this.withNetname(instance.getNetname()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.NetNamespaceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.NetNamespace build() {
    NetNamespace buildable = new NetNamespace(fluent.getApiVersion(),fluent.getEgressIPs(),fluent.getKind(),fluent.getMetadata(),fluent.getNetid(),fluent.getNetname());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetNamespaceBuilder that = (NetNamespaceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
